@@ -36,6 +36,7 @@ protected:
 	void keyPressEvent(QKeyEvent *event);
 	void keyReleaseEvent(QKeyEvent *event);
 private:
+	QDBusInterface *qDBusInterface;
 	QMainWindow *parentti;
 	GLfloat *projection;
 	MD2Model *md2;
@@ -45,7 +46,7 @@ private:
 	bool noukkiminen;
 	bool lopussa;
 	float speed;
-	QTime duration;
+	QTimer *aikaKello;
 	QTime time;
 	QTimer *timer;
 	int frames;
@@ -54,6 +55,8 @@ private:
 	QPainter painter;
 	QDBusInterface *interface;
 	void Plane();
+	void pauseGame();
+	void resumeGame();
 
 	GLuint program;
 	QImage qim;
@@ -85,7 +88,10 @@ private slots:
 	void paivita();
 	void avoidScreensaver();
 	void hideGame();
-	
+	void displayStateError(const QDBusError &);
+	void setDisplayState(const QString&);
+	void displayStateChanged(const QDBusMessage &);
+	void lisaaAikaa();
 public slots:
 
 
